@@ -1,11 +1,11 @@
 /* vim: set expandtab ts=8 sw=4: */
 
-/*  $Id: xfce-itembar.c 23200 2006-09-24 08:57:47Z jasper $
+/*  $Id: xfce-itembar.c 25904 2007-07-09 13:01:57Z nick $
  *
  *  Copyright © 2004-2005 Jasper Huijsmans <jasper@xfce.org>
  *
  *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Library General Public License as published 
+ *  it under the terms of the GNU Library General Public License as published
  *  by the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
@@ -65,16 +65,17 @@ enum
 typedef struct _XfceItembarChild   XfceItembarChild;
 typedef struct _XfceItembarPrivate XfceItembarPrivate;
 
-struct _XfceItembarPrivate 
+struct _XfceItembarPrivate
 {
     GtkOrientation orientation;
     GList *children;
-    
+
     GdkWindow *event_window;
     GdkWindow *drag_highlight;
-    
+
     int drop_index;
     guint raised:1;
+    guint expand_allowed:1;
 };
 
 struct _XfceItembarChild
@@ -98,7 +99,7 @@ static void xfce_itembar_set_property       (GObject * object,
 
 static void xfce_itembar_get_property       (GObject * object,
 				             guint prop_id,
-				             GValue * value, 
+				             GValue * value,
                                              GParamSpec * pspec);
 
 /* widget */
@@ -120,20 +121,20 @@ static void xfce_itembar_map                (GtkWidget * widget);
 static void xfce_itembar_unmap              (GtkWidget * widget);
 
 static void xfce_itembar_drag_leave         (GtkWidget * widget,
-				             GdkDragContext * context, 
+				             GdkDragContext * context,
                                              guint time_);
 
 static gboolean xfce_itembar_drag_motion    (GtkWidget * widget,
 					     GdkDragContext * context,
-					     int x, 
-                                             int y, 
+					     int x,
+                                             int y,
                                              guint time_);
 
 
 /* container */
 static void xfce_itembar_forall             (GtkContainer * container,
 		                             gboolean include_internals,
-		                             GtkCallback callback, 
+		                             GtkCallback callback,
                                              gpointer callback_data);
 
 static GType xfce_itembar_child_type        (GtkContainer * container);
@@ -143,7 +144,7 @@ static void xfce_itembar_add                (GtkContainer * container,
 
 static void xfce_itembar_remove             (GtkContainer * container,
                                              GtkWidget * child);
-    
+
 static void xfce_itembar_set_child_property (GtkContainer * container,
                                              GtkWidget * child,
 				             guint prop_id,
@@ -153,12 +154,12 @@ static void xfce_itembar_set_child_property (GtkContainer * container,
 static void xfce_itembar_get_child_property (GtkContainer * container,
                                              GtkWidget * child,
 				             guint prop_id,
-				             GValue * value, 
+				             GValue * value,
                                              GParamSpec * pspec);
 
 /* internal functions */
-static int _find_drop_index                 (XfceItembar * itembar, 
-                                             int x, 
+static int _find_drop_index                 (XfceItembar * itembar,
+                                             int x,
                                              int y);
 
 /* global vars */
@@ -188,7 +189,7 @@ xfce_itembar_get_type (void)
             NULL
 	};
 
-	type = g_type_register_static (GTK_TYPE_CONTAINER, "XfceItembar", 
+	type = g_type_register_static (GTK_TYPE_CONTAINER, "XfceItembar",
                                        &type_info, 0);
     }
 
@@ -215,9 +216,9 @@ xfce_itembar_class_init (XfceItembarClass * klass)
     gobject_class->get_property         = xfce_itembar_get_property;
     gobject_class->set_property         = xfce_itembar_set_property;
 
-    widget_class->expose_event          = xfce_itembar_expose;    
-    widget_class->size_request          = xfce_itembar_size_request;    
-    widget_class->size_allocate         = xfce_itembar_size_allocate;    
+    widget_class->expose_event          = xfce_itembar_expose;
+    widget_class->size_request          = xfce_itembar_size_request;
+    widget_class->size_allocate         = xfce_itembar_size_allocate;
     widget_class->realize               = xfce_itembar_realize;
     widget_class->unrealize             = xfce_itembar_unrealize;
     widget_class->map                   = xfce_itembar_map;
@@ -245,12 +246,12 @@ xfce_itembar_class_init (XfceItembarClass * klass)
         g_signal_new ("orientation-changed",
                       G_OBJECT_CLASS_TYPE (klass),
                       G_SIGNAL_RUN_FIRST,
-                      G_STRUCT_OFFSET (XfceItembarClass, 
+                      G_STRUCT_OFFSET (XfceItembarClass,
                                        orientation_changed),
                       NULL, NULL,
                       g_cclosure_marshal_VOID__ENUM,
                       G_TYPE_NONE, 1, GTK_TYPE_ORIENTATION);
-    
+
     /**
      * XfceItembar::contents-changed:
      * @itembar     : the object which emitted the signal
@@ -262,12 +263,12 @@ xfce_itembar_class_init (XfceItembarClass * klass)
         g_signal_new ("contents-changed",
                       G_OBJECT_CLASS_TYPE (klass),
                       G_SIGNAL_RUN_FIRST,
-                      G_STRUCT_OFFSET (XfceItembarClass, 
+                      G_STRUCT_OFFSET (XfceItembarClass,
                                        contents_changed),
                       NULL, NULL,
                       g_cclosure_marshal_VOID__VOID,
                       G_TYPE_NONE, 0);
-    
+
     /* properties */
 
     /**
@@ -275,15 +276,15 @@ xfce_itembar_class_init (XfceItembarClass * klass)
      *
      * The orientation of the #XfceItembar.
      **/
-    g_object_class_install_property (gobject_class, 
-            PROP_ORIENTATION, 
+    g_object_class_install_property (gobject_class,
+            PROP_ORIENTATION,
             g_param_spec_enum ("orientation",
 			       "Orientation",
 			       "The orientation of the itembar",
 			       GTK_TYPE_ORIENTATION,
-			       DEFAULT_ORIENTATION, 
+			       DEFAULT_ORIENTATION,
                                G_PARAM_READWRITE));
-    
+
     /* child properties */
 
     /**
@@ -292,19 +293,19 @@ xfce_itembar_class_init (XfceItembarClass * klass)
      * Whether the child of the #XfceItembar should fill available space.
      **/
     gtk_container_class_install_child_property (container_class,
-            CHILD_PROP_EXPAND, 
-            g_param_spec_boolean ("expand", 
-                                  "Expand", 
+            CHILD_PROP_EXPAND,
+            g_param_spec_boolean ("expand",
+                                  "Expand",
                                   "Whether to grow with parent",
                                   DEFAULT_CHILD_EXPAND,
-                                  G_PARAM_READWRITE));    
+                                  G_PARAM_READWRITE));
 }
 
 static void
 xfce_itembar_init (XfceItembar * itembar)
 {
     XfceItembarPrivate *priv = XFCE_ITEMBAR_GET_PRIVATE (itembar);
-    
+
     GTK_WIDGET_SET_FLAGS (GTK_WIDGET (itembar), GTK_NO_WINDOW);
     gtk_widget_set_redraw_on_allocate (GTK_WIDGET (itembar), FALSE);
 
@@ -313,6 +314,8 @@ xfce_itembar_init (XfceItembar * itembar)
     priv->event_window     = NULL;
     priv->drag_highlight   = NULL;
     priv->drop_index       = -1;
+    priv->raised           = FALSE;
+    priv->expand_allowed   = FALSE;
 }
 
 /* GObject */
@@ -361,7 +364,7 @@ xfce_itembar_get_property (GObject * object, guint prop_id, GValue * value,
 static int
 xfce_itembar_expose (GtkWidget * widget, GdkEventExpose *event)
 {
-    XfceItembarPrivate *priv = 
+    XfceItembarPrivate *priv =
         XFCE_ITEMBAR_GET_PRIVATE (XFCE_ITEMBAR (widget));
 
     GTK_WIDGET_CLASS (parent_class)->expose_event (widget, event);
@@ -375,16 +378,16 @@ xfce_itembar_expose (GtkWidget * widget, GdkEventExpose *event)
 static void
 xfce_itembar_size_request (GtkWidget * widget, GtkRequisition * requisition)
 {
-    XfceItembarPrivate *priv = 
+    XfceItembarPrivate *priv =
         XFCE_ITEMBAR_GET_PRIVATE (XFCE_ITEMBAR (widget));
     GList *l;
     int max, other_size;
 
-    requisition->width = requisition->height = 
+    requisition->width = requisition->height =
         2 * GTK_CONTAINER (widget)->border_width;
-    
+
     max = other_size = 0;
-    
+
     for (l = priv->children; l != NULL; l = l->next)
     {
         XfceItembarChild *child = l->data;
@@ -394,7 +397,7 @@ xfce_itembar_size_request (GtkWidget * widget, GtkRequisition * requisition)
             continue;
 
         gtk_widget_size_request (child->widget, &req);
-        
+
         if (GTK_ORIENTATION_HORIZONTAL == priv->orientation)
         {
             max = MAX (max, req.height);
@@ -424,142 +427,146 @@ xfce_itembar_size_request (GtkWidget * widget, GtkRequisition * requisition)
 static void
 xfce_itembar_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
 {
-    XfceItembarPrivate *priv = 
-        XFCE_ITEMBAR_GET_PRIVATE (XFCE_ITEMBAR (widget));
-    int n, i, x, y, bar_height, total_size;
-    int n_expand, expand_width, max_expand, total_expand;
-    int border_width;
-    GList *l;
-    GtkTextDirection direction;
-    struct ItemProps { 
-        GtkAllocation allocation;
-        gboolean expand; 
-    } *props;
-    
+    XfceItembarPrivate *priv;
+    XfceItembarChild   *child;
+    GtkRequisition      req;
+    GtkTextDirection    direction;
+    GList              *l;
+    gint                n_total, i;
+    gint                x, y, width, height, size;
+    gint                border_width, bar_height, total_size;
+    gint                n_expand, expand_width, max_expand, total_expand;
+    gboolean            horizontal;
+    struct ItemProps
+    {
+        GtkAllocation       allocation;
+        gboolean            expand;
+    }                  *props;
+
+    /* itembar allocation */
     widget->allocation = *allocation;
 
-    border_width = GTK_CONTAINER (widget)->border_width;
-    
-    n_expand = expand_width = max_expand = 0;
-    bar_height = total_size = 0;
+    priv         = XFCE_ITEMBAR_GET_PRIVATE (XFCE_ITEMBAR (widget));
+    horizontal   = (GTK_ORIENTATION_HORIZONTAL == priv->orientation);
 
-    x = allocation->x + border_width;
-    y = allocation->y + border_width;
-    
-    if (GTK_ORIENTATION_HORIZONTAL == priv->orientation)
+    border_width = GTK_CONTAINER (widget)->border_width;
+    x            = allocation->x + border_width;
+    y            = allocation->y + border_width;
+
+    if (horizontal)
     {
-        expand_width = allocation->width - 2 * border_width;
+        total_size = allocation->width - 2 * border_width;
         bar_height = allocation->height - 2 * border_width;
 
         if (priv->event_window != NULL)
         {
-            gdk_window_move_resize (priv->event_window, 
-                                    x, y, expand_width, bar_height);
+            gdk_window_move_resize (priv->event_window,
+                                    x, y, total_size, bar_height);
         }
     }
     else
     {
-        expand_width = allocation->height - 2 * border_width;
+        total_size = allocation->height - 2 * border_width;
         bar_height = allocation->width - 2 * border_width;
 
         if (priv->event_window != NULL)
         {
-            gdk_window_move_resize (priv->event_window, 
-                                    x, y, bar_height, expand_width);
+            gdk_window_move_resize (priv->event_window,
+                                    x, y, bar_height, total_size);
         }
     }
 
-    total_size = expand_width;
-    direction = gtk_widget_get_direction (widget);
+    total_expand = total_size;
+    direction    = gtk_widget_get_direction (widget);
+    n_total      = g_list_length (priv->children);
+    props        = g_new (struct ItemProps, n_total);
 
-    n = g_list_length (priv->children);
+    n_expand = expand_width = max_expand = 0;
 
-    props = g_new (struct ItemProps, n);
-    
-    /* first pass */
+    /* - get size request for all items
+     * - get number of expanding items
+     * - determine space available for expanding items
+     * - determine largest width of expanding items
+     */
     for (l = priv->children, i = 0; l != NULL; l = l->next, i++)
     {
-        XfceItembarChild *child = l->data;
-        int width, height;
-        GtkRequisition req;
+        child = l->data;
 
         if (!GTK_WIDGET_VISIBLE (child->widget))
         {
             props[i].allocation.width = 0;
             continue;
         }
-        
-        gtk_widget_size_request (child->widget, &req);
-        width = req.width;
-        height = req.height;
 
-        if (GTK_ORIENTATION_HORIZONTAL == priv->orientation)
+        gtk_widget_size_request (child->widget, &req);
+
+        if (horizontal)
         {
+            width  = req.width;
             height = bar_height;
-            
-            if (child->expand)
+
+            if (child->expand && priv->expand_allowed)
             {
                 n_expand++;
                 max_expand = MAX (max_expand, width);
             }
             else
             {
-                expand_width -= width;
+                total_expand -= width;
             }
         }
         else
         {
-            width = bar_height;
-            
-            if (child->expand)
+            height = req.height;
+            width  = bar_height;
+
+            if (child->expand && priv->expand_allowed)
             {
                 n_expand++;
                 max_expand = MAX (max_expand, height);
             }
             else
             {
-                expand_width -= height;
+                total_expand -= height;
             }
         }
 
-        props[i].allocation.width = width;
+        props[i].allocation.width  = width;
         props[i].allocation.height = height;
-        props[i].expand = child->expand;
+        props[i].expand = (child->expand && priv->expand_allowed);
     }
 
-    total_expand = expand_width;
-    
+    /* check if expanding items fit */
     while (n_expand > 0)
     {
-        int real_expand_width = 
-            MAX (expand_width / n_expand, 0);
+        /* space available for 1 expanding item */
+        expand_width = MAX (total_expand / n_expand, 0);
 
-        /* if it fits, continue */
-        if (real_expand_width >= max_expand)
+        /* if it fits, we're done */
+        if (expand_width >= max_expand)
         {
-            expand_width = real_expand_width;
             break;
         }
 
         max_expand = 0;
-        
-        /* remove bigger items from expand list */
-        for (i = 0; i < n; ++i)
+
+        /* - remove bigger items from expand list
+         * - recalculate n_expand, total_expand and max_expand
+         */
+        for (i = 0; i < n_total; ++i)
         {
-            int size;
-            
             if (!props[i].expand)
                 continue;
-            
-            if (GTK_ORIENTATION_HORIZONTAL == priv->orientation)
+
+            if (horizontal)
                 size = props[i].allocation.width;
             else
                 size = props[i].allocation.height;
 
-            if (size > real_expand_width)
+            if (size > expand_width)
             {
                 props[i].expand = FALSE;
-                expand_width -= size;
+                total_expand -= size;
                 n_expand--;
             }
             else
@@ -568,21 +575,21 @@ xfce_itembar_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
             }
         }
     }
-    
+
     x = y = border_width;
-    
-    /* second pass */
+
+    /* allocate items */
     for (l = priv->children, i = 0; l != NULL; l = l->next, i++)
     {
-        XfceItembarChild *child = l->data;
-        
+        child = l->data;
+
         if (props[i].allocation.width == 0)
             continue;
 
         props[i].allocation.x = x + allocation->x;
         props[i].allocation.y = y + allocation->y;
 
-        if (GTK_ORIENTATION_HORIZONTAL == priv->orientation)
+        if (horizontal)
         {
             /* to cope with rounding errors, the last expanded child
              * gets all of the remaining expanded space */
@@ -590,7 +597,7 @@ xfce_itembar_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
             {
                 if (n_expand == 1)
                     expand_width = total_expand;
-                
+
                 props[i].allocation.width = expand_width;
                 n_expand--;
                 total_expand -= expand_width;
@@ -598,7 +605,7 @@ xfce_itembar_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
 
             if (direction == GTK_TEXT_DIR_RTL)
             {
-                props[i].allocation.x = allocation->x + total_size - x 
+                props[i].allocation.x = allocation->x + total_size - x
                                         - props[i].allocation.width;
             }
 
@@ -611,9 +618,8 @@ xfce_itembar_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
 
             y += props[i].allocation.height;
         }
-        
-        gtk_widget_size_allocate (child->widget, 
-                                  &(props[i].allocation));
+
+      gtk_widget_size_allocate (child->widget, &(props[i].allocation));
     }
 
     g_free (props);
@@ -646,8 +652,8 @@ xfce_itembar_realize (GtkWidget * widget)
         | GDK_BUTTON_MOTION_MASK
         | GDK_BUTTON_PRESS_MASK
         | GDK_BUTTON_RELEASE_MASK
-        | GDK_EXPOSURE_MASK 
-        | GDK_ENTER_NOTIFY_MASK 
+        | GDK_EXPOSURE_MASK
+        | GDK_ENTER_NOTIFY_MASK
         | GDK_LEAVE_NOTIFY_MASK;
     attributes.wclass = GDK_INPUT_ONLY;
     attributes_mask = GDK_WA_X | GDK_WA_Y;
@@ -693,7 +699,7 @@ xfce_itembar_map (GtkWidget * widget)
     gdk_window_show (priv->event_window);
 
     (*GTK_WIDGET_CLASS (parent_class)->map) (widget);
-    
+
     if (priv->raised)
         gdk_window_raise (priv->event_window);
 }
@@ -755,7 +761,7 @@ xfce_itembar_drag_motion (GtkWidget * widget,
 	attributes.width = 1;
 	attributes.height = 1;
 	attributes_mask = GDK_WA_VISUAL | GDK_WA_COLORMAP;
-	priv->drag_highlight = 
+	priv->drag_highlight =
             gdk_window_new (gtk_widget_get_parent_window (widget),
 		            &attributes, attributes_mask);
 	gdk_window_set_user_data (priv->drag_highlight, widget);
@@ -768,7 +774,7 @@ xfce_itembar_drag_motion (GtkWidget * widget,
 	int border_width = GTK_CONTAINER (itembar)->border_width;
 
         child = g_list_nth_data (priv->children, new_index);
-	
+
 	priv->drop_index = new_index;
 	if (priv->orientation == GTK_ORIENTATION_HORIZONTAL)
 	{
@@ -777,7 +783,7 @@ xfce_itembar_drag_motion (GtkWidget * widget,
 	    else
 		new_pos = widget->allocation.x + widget->allocation.width
                           - border_width;
-	    
+
 	    gdk_window_move_resize (priv->drag_highlight, new_pos - 1,
 				    widget->allocation.y + border_width, 2,
 				    widget->allocation.height -
@@ -789,7 +795,7 @@ xfce_itembar_drag_motion (GtkWidget * widget,
 		new_pos = child->widget->allocation.y;
 	    else
 		new_pos = widget->allocation.y + widget->allocation.height;
-	    
+
 	    gdk_window_move_resize (priv->drag_highlight,
 				    widget->allocation.x + border_width,
 				    new_pos - 1, widget->allocation.width
@@ -809,13 +815,13 @@ xfce_itembar_forall (GtkContainer * container, gboolean include_internals,
                      GtkCallback callback, gpointer callback_data)
 {
     GList *l;
-    XfceItembarPrivate *priv = 
+    XfceItembarPrivate *priv =
         XFCE_ITEMBAR_GET_PRIVATE (XFCE_ITEMBAR (container));
 
     for (l = priv->children; l != NULL; l = l->next)
     {
         XfceItembarChild *child = l->data;
-        
+
         if (child && GTK_IS_WIDGET (child->widget))
             (*callback) (child->widget, callback_data);
     }
@@ -838,13 +844,13 @@ xfce_itembar_remove (GtkContainer * container, GtkWidget *child)
 {
     XfceItembarPrivate *priv;
     GList *l;
-    
+
     g_return_if_fail (XFCE_IS_ITEMBAR (container));
-    g_return_if_fail (child != NULL 
+    g_return_if_fail (child != NULL
                       && child->parent == GTK_WIDGET (container));
 
     priv = XFCE_ITEMBAR_GET_PRIVATE (XFCE_ITEMBAR (container));
-    
+
     for (l = priv->children; l != NULL; l = l->next)
     {
         XfceItembarChild *ic = l->data;
@@ -852,19 +858,19 @@ xfce_itembar_remove (GtkContainer * container, GtkWidget *child)
         if (ic->widget == child)
         {
             gboolean was_visible;
-            
+
             priv->children = g_list_delete_link (priv->children, l);
 
             was_visible = GTK_WIDGET_VISIBLE (ic->widget);
-            
+
             gtk_widget_unparent (ic->widget);
 
             panel_slice_free (XfceItembarChild, ic);
 
             if (was_visible)
                 gtk_widget_queue_resize (GTK_WIDGET (container));
-            
-            g_signal_emit (G_OBJECT (container), 
+
+            g_signal_emit (G_OBJECT (container),
                            itembar_signals [CONTENTS_CHANGED], 0);
 
             break;
@@ -922,16 +928,16 @@ _find_drop_index (XfceItembar * itembar, int x, int y)
     XfceItembarChild *child;
     XfceItembarPrivate *priv = XFCE_ITEMBAR_GET_PRIVATE (itembar);
     int best_distance = G_MAXINT;
-    
+
     if (!priv->children)
         return 0;
-    
+
     direction = gtk_widget_get_direction (GTK_WIDGET (itembar));
 
     index = 0;
-    
+
     child = priv->children->data;
-    
+
     if (GTK_ORIENTATION_HORIZONTAL == priv->orientation)
     {
         cursor =  x;
@@ -943,7 +949,7 @@ _find_drop_index (XfceItembar * itembar, int x, int y)
         }
         else
         {
-            pos = child->widget->allocation.x 
+            pos = child->widget->allocation.x
                   + child->widget->allocation.width - x;
         }
     }
@@ -954,7 +960,7 @@ _find_drop_index (XfceItembar * itembar, int x, int y)
 
         pos = child->widget->allocation.y - y;
     }
-    
+
     best_distance = ABS (pos - cursor);
 
     /* distance to far end of each item */
@@ -965,14 +971,14 @@ _find_drop_index (XfceItembar * itembar, int x, int y)
 	if (priv->orientation == GTK_ORIENTATION_HORIZONTAL)
 	{
 	    if (direction == GTK_TEXT_DIR_LTR)
-		pos = child->widget->allocation.x 
+		pos = child->widget->allocation.x
                       + child->widget->allocation.width - x;
 	    else
 		pos = child->widget->allocation.x - x;
 	}
 	else
 	{
-	    pos = y + child->widget->allocation.y 
+	    pos = y + child->widget->allocation.y
                   + child->widget->allocation.height - y;
 	}
 
@@ -1002,23 +1008,47 @@ xfce_itembar_new (GtkOrientation orientation)
 {
     XfceItembar *itembar;
 
-    itembar = g_object_new (XFCE_TYPE_ITEMBAR, "orientation", orientation, 
+    itembar = g_object_new (XFCE_TYPE_ITEMBAR, "orientation", orientation,
                             NULL);
 
     return GTK_WIDGET (itembar);
 }
 
+/**
+ * xfce_itembar_set_allow_expand:
+ * @allow : %TRUE when the expansion is allowed.
+ *
+ * Set whether the 'expand' child property is honored.
+ *
+ * See also: xfce_itembar_set_child_expand().
+ **/
+void
+xfce_itembar_set_allow_expand (XfceItembar *itembar,
+                               gboolean     allow)
+{
+    XfceItembarPrivate *priv;
+
+    g_return_if_fail (XFCE_IS_ITEMBAR (itembar));
+
+    priv = XFCE_ITEMBAR_GET_PRIVATE (itembar);
+
+    priv->expand_allowed = allow;
+    gtk_widget_queue_resize (GTK_WIDGET(itembar));
+}
+
+
+
 /**
  * xfce_itembar_get_orientation:
  * @itembar : an #XfceItembar
  *
  * Returns: #GtkOrienation of @itembar.
  **/
-GtkOrientation 
+GtkOrientation
 xfce_itembar_get_orientation (XfceItembar * itembar)
 {
     XfceItembarPrivate *priv;
-    
+
     g_return_val_if_fail (XFCE_IS_ITEMBAR (itembar), DEFAULT_ORIENTATION);
 
     priv = XFCE_ITEMBAR_GET_PRIVATE (itembar);
@@ -1033,11 +1063,11 @@ xfce_itembar_get_orientation (XfceItembar * itembar)
  *
  * Set the orienation of @itembar.
  **/
-void 
+void
 xfce_itembar_set_orientation (XfceItembar * itembar, GtkOrientation orientation)
 {
     XfceItembarPrivate *priv;
-    
+
     g_return_if_fail (XFCE_IS_ITEMBAR (itembar));
 
     priv = XFCE_ITEMBAR_GET_PRIVATE (itembar);
@@ -1047,7 +1077,7 @@ xfce_itembar_set_orientation (XfceItembar * itembar, GtkOrientation orientation)
 
     priv->orientation = orientation;
 
-    g_signal_emit (itembar, itembar_signals[ORIENTATION_CHANGED], 0, 
+    g_signal_emit (itembar, itembar_signals[ORIENTATION_CHANGED], 0,
                    orientation);
 
     g_object_notify (G_OBJECT (itembar), "orientation");
@@ -1069,21 +1099,21 @@ xfce_itembar_insert (XfceItembar * itembar, GtkWidget * item, int position)
 {
     XfceItembarPrivate *priv;
     XfceItembarChild *child;
-    
+
     g_return_if_fail (XFCE_IS_ITEMBAR (itembar));
     g_return_if_fail (item != NULL && GTK_WIDGET (item)->parent == NULL);
 
     priv = XFCE_ITEMBAR_GET_PRIVATE (itembar);
-    
+
     child = panel_slice_new0 (XfceItembarChild);
     child->widget = item;
-    
+
     priv->children = g_list_insert (priv->children, child, position);
 
     gtk_widget_set_parent (GTK_WIDGET (item), GTK_WIDGET (itembar));
 
     gtk_widget_queue_resize (GTK_WIDGET (itembar));
-    
+
     g_signal_emit (G_OBJECT (itembar), itembar_signals [CONTENTS_CHANGED], 0);
 }
 
@@ -1127,13 +1157,13 @@ xfce_itembar_reorder_child (XfceItembar * itembar, GtkWidget * item,
 {
     XfceItembarPrivate *priv;
     GList *l;
-    
+
     g_return_if_fail (XFCE_IS_ITEMBAR (itembar));
-    g_return_if_fail (item != NULL 
+    g_return_if_fail (item != NULL
                       && GTK_WIDGET (item)->parent == GTK_WIDGET (itembar));
 
     priv = XFCE_ITEMBAR_GET_PRIVATE (XFCE_ITEMBAR (itembar));
-    
+
     for (l = priv->children; l != NULL; l = l->next)
     {
         XfceItembarChild *child = l->data;
@@ -1145,8 +1175,8 @@ xfce_itembar_reorder_child (XfceItembar * itembar, GtkWidget * item,
             priv->children = g_list_insert (priv->children, child, position);
 
             gtk_widget_queue_resize (GTK_WIDGET (itembar));
-            
-            g_signal_emit (G_OBJECT (itembar), 
+
+            g_signal_emit (G_OBJECT (itembar),
                            itembar_signals [CONTENTS_CHANGED], 0);
 
             break;
@@ -1162,19 +1192,19 @@ xfce_itembar_reorder_child (XfceItembar * itembar, GtkWidget * item,
  * Returns: %TRUE if @item will expand when the size of @itembar increases,
  *          otherwise %FALSE.
  **/
-gboolean 
+gboolean
 xfce_itembar_get_child_expand (XfceItembar * itembar, GtkWidget * item)
 {
     XfceItembarPrivate *priv;
     GList *l;
-    
+
     g_return_val_if_fail (XFCE_IS_ITEMBAR (itembar), FALSE);
-    g_return_val_if_fail (item != NULL && 
+    g_return_val_if_fail (item != NULL &&
                           GTK_WIDGET (item)->parent == GTK_WIDGET (itembar),
                           FALSE);
 
     priv = XFCE_ITEMBAR_GET_PRIVATE (XFCE_ITEMBAR (itembar));
-    
+
     for (l = priv->children; l != NULL; l = l->next)
     {
         XfceItembarChild *child = l->data;
@@ -1196,19 +1226,19 @@ xfce_itembar_get_child_expand (XfceItembar * itembar, GtkWidget * item)
  *
  * Sets whether @item should expand when the size of @itembar increases.
  **/
-void 
+void
 xfce_itembar_set_child_expand (XfceItembar * itembar, GtkWidget * item,
                                gboolean expand)
 {
     XfceItembarPrivate *priv;
     GList *l;
-    
+
     g_return_if_fail (XFCE_IS_ITEMBAR (itembar));
-    g_return_if_fail (item != NULL 
+    g_return_if_fail (item != NULL
                       && GTK_WIDGET (item)->parent == GTK_WIDGET (itembar));
 
     priv = XFCE_ITEMBAR_GET_PRIVATE (XFCE_ITEMBAR (itembar));
-    
+
     for (l = priv->children; l != NULL; l = l->next)
     {
         XfceItembarChild *child = l->data;
@@ -1233,11 +1263,11 @@ int
 xfce_itembar_get_n_items (XfceItembar * itembar)
 {
     XfceItembarPrivate *priv;
-    
+
     g_return_val_if_fail (XFCE_IS_ITEMBAR (itembar), 0);
 
     priv = XFCE_ITEMBAR_GET_PRIVATE (XFCE_ITEMBAR (itembar));
-    
+
     return g_list_length (priv->children);
 }
 
@@ -1254,14 +1284,14 @@ xfce_itembar_get_item_index (XfceItembar * itembar, GtkWidget * item)
     XfceItembarPrivate *priv;
     GList *l;
     int n;
-    
+
     g_return_val_if_fail (XFCE_IS_ITEMBAR (itembar), -1);
-    g_return_val_if_fail (item != NULL 
-                                && GTK_WIDGET (item)->parent 
+    g_return_val_if_fail (item != NULL
+                                && GTK_WIDGET (item)->parent
                                         == GTK_WIDGET (itembar), -1);
 
     priv = XFCE_ITEMBAR_GET_PRIVATE (XFCE_ITEMBAR (itembar));
-    
+
     for (n = 0, l = priv->children; l != NULL; l = l->next, ++n)
     {
         XfceItembarChild *child = l->data;
@@ -1309,7 +1339,7 @@ xfce_itembar_get_nth_item (XfceItembar * itembar, int n)
  * @itembar : an #XfceItembar
  *
  * Raise the event window of @itembar. This causes all events, like
- * mouse clicks or key presses to be send to the itembar and not to 
+ * mouse clicks or key presses to be send to the itembar and not to
  * any item.
  *
  * See also: xfce_itembar_lower_event_window()
@@ -1385,21 +1415,21 @@ xfce_itembar_get_item_at_point (XfceItembar * itembar, int x, int y)
 {
     XfceItembarPrivate *priv;
     GList *l;
-    
+
     g_return_val_if_fail (XFCE_IS_ITEMBAR (itembar), NULL);
 
     priv = XFCE_ITEMBAR_GET_PRIVATE (itembar);
 
     x += GTK_WIDGET (itembar)->allocation.x;
     y += GTK_WIDGET (itembar)->allocation.y;
-    
+
     for (l = priv->children; l != NULL; l = l->next)
     {
         XfceItembarChild *child = l->data;
         GtkWidget *w = child->widget;
         GtkAllocation *a = &(w->allocation);
 
-        if (x >= a->x && x < a->x + a->width 
+        if (x >= a->x && x < a->x + a->width
             && y >= a->y && y < a->y + a->height)
         {
             return w;
@@ -1421,8 +1451,8 @@ xfce_itembar_get_item_at_point (XfceItembar * itembar, int x, int y)
  * inserted.
  *
  * @x and @y are in @itembar coordinates.
- * 
- * Returns: The position corresponding to the point (@x, @y) on the 
+ *
+ * Returns: The position corresponding to the point (@x, @y) on the
  * itembar.
  **/
 int
