@@ -1,6 +1,6 @@
 /* vim: set expandtab ts=8 sw=4: */
 
-/*  $Id: xfce-panel-external-item.c 23200 2006-09-24 08:57:47Z jasper $
+/*  $Id: xfce-panel-external-item.c 24267 2007-01-04 17:51:35Z nick $
  *
  *  Copyright © 2005 Jasper Huijsmans <jasper@xfce.org>
  *
@@ -51,6 +51,9 @@ struct _XfceExternalPanelItemPrivate
     guint expand:1;
     /* detect problems */
     guint to_be_removed:1;
+    guint restart:1;
+
+    char *file;
 };
 
 
@@ -101,6 +104,8 @@ static gboolean _item_event_received (XfceExternalPanelItem * item,
 
 static void _item_construct (XfceExternalPanelItem * item);
 
+static void _item_screen_changed (XfceExternalPanelItem * item, GdkScreen *screen);
+
 static void _item_setup (XfceExternalPanelItem * item, const char *file);
 
 
@@ -159,6 +164,8 @@ xfce_external_panel_item_init (XfceExternalPanelItem * item)
     priv->screen_position = XFCE_SCREEN_POSITION_NONE;
     priv->expand          = FALSE;
     priv->to_be_removed   = FALSE;
+    priv->restart         = FALSE;
+    priv->file            = NULL;
 }
 
 /* GObject */
@@ -179,6 +186,7 @@ xfce_external_panel_item_finalize (GObject * object)
     g_free (priv->name);
     g_free (priv->id);
     g_free (priv->display_name);
+    g_free (priv->file);
 
     G_OBJECT_CLASS (xfce_external_panel_item_parent_class)->finalize (object);
 }
@@ -344,13 +352,8 @@ static void
 xfce_external_panel_item_set_sensitive (XfcePanelItem * item, 
                                         gboolean sensitive)
 {
-    XfceExternalPanelItemPrivate *priv;
-
     g_return_if_fail (XFCE_IS_EXTERNAL_PANEL_ITEM (item));
 
-    priv = XFCE_EXTERNAL_PANEL_ITEM_GET_PRIVATE (
-                XFCE_EXTERNAL_PANEL_ITEM (item));
-
     if (GDK_IS_WINDOW (GTK_SOCKET (item)->plug_window))
     {
         xfce_panel_plugin_message_send (GTK_WIDGET (item)->window,
@@ -369,13 +372,8 @@ xfce_external_panel_item_set_sensitive (XfcePanelItem * item,
 static void 
 xfce_external_panel_item_remove (XfcePanelItem * item)
 {
-    XfceExternalPanelItemPrivate *priv;
-
     g_return_if_fail (XFCE_IS_EXTERNAL_PANEL_ITEM (item));
 
-    priv = XFCE_EXTERNAL_PANEL_ITEM_GET_PRIVATE (
-                XFCE_EXTERNAL_PANEL_ITEM (item));
-
     xfce_panel_plugin_message_send (GTK_WIDGET (item)->window,
             GDK_WINDOW_XID (GTK_SOCKET (item)->plug_window),
             XFCE_PANEL_PLUGIN_REMOVE, 0);
@@ -394,13 +392,8 @@ delayed_configure(XfcePanelItem *item)
 static void 
 xfce_external_panel_item_configure (XfcePanelItem * item)
 {
-    XfceExternalPanelItemPrivate *priv;
-
     g_return_if_fail (XFCE_IS_EXTERNAL_PANEL_ITEM (item));
 
-    priv = XFCE_EXTERNAL_PANEL_ITEM_GET_PRIVATE (
-                XFCE_EXTERNAL_PANEL_ITEM (item));
-
     if (GDK_IS_WINDOW (GTK_SOCKET (item)->plug_window))
     {
         xfce_panel_plugin_message_send (GTK_WIDGET (item)->window,
@@ -479,6 +472,37 @@ _item_construct (XfceExternalPanelItem * item)
                                     XFCE_PANEL_PLUGIN_CONSTRUCT, 0);
 }
 
+static void
+_item_screen_changed (XfceExternalPanelItem *item, 
+                      GdkScreen             *screen)
+{
+    XfceExternalPanelItemPrivate *priv;
+
+    priv = XFCE_EXTERNAL_PANEL_ITEM_GET_PRIVATE (XFCE_EXTERNAL_PANEL_ITEM (item));
+    
+    /* quit when we're going to close the plugin */
+    if (priv->to_be_removed == TRUE)
+        return;
+
+    screen = gtk_widget_get_screen (GTK_WIDGET (item));
+    g_message ("%s: screen changed: %d\n",
+               xfce_external_panel_item_get_display_name (XFCE_PANEL_ITEM (item)),
+               gdk_screen_get_number (screen));
+
+    if (GTK_SOCKET(item)->plug_window)
+    {
+        xfce_panel_plugin_message_send (GTK_WIDGET (item)->window,
+            GDK_WINDOW_XID (GTK_SOCKET (item)->plug_window),
+            XFCE_PANEL_PLUGIN_SIZE, priv->size);
+    }
+    else
+    {
+        g_message ("No valid plug window.");
+        priv->restart = TRUE;
+        _item_setup (item, priv->file);
+    }
+}
+
 static void
 _item_setup (XfceExternalPanelItem * item, const char *file)
 {
@@ -507,10 +531,13 @@ _item_setup (XfceExternalPanelItem * item, const char *file)
     argv[6] = g_strdup_printf ("screen_position=%d", priv->screen_position);
     argv[7] = NULL;
 
-    g_signal_connect (item, "plug-added", G_CALLBACK (_item_construct), NULL);
+    if (!priv->restart)
+    {
+        g_signal_connect (item, "plug-added", G_CALLBACK (_item_construct), NULL);
 
-    g_signal_connect (item, "client-event",
-                      G_CALLBACK (_item_event_received), NULL);
+        g_signal_connect (item, "client-event",
+                          G_CALLBACK (_item_event_received), NULL);
+    }
 
     gscreen = gtk_widget_get_screen (GTK_WIDGET (item));
     gdkdisplay_name = gdk_screen_make_display_name (gscreen);
@@ -521,6 +548,7 @@ _item_setup (XfceExternalPanelItem * item, const char *file)
             g_critical ("Could not run plugin: %s", g_strerror (errno));
             gtk_widget_destroy (GTK_WIDGET (item));
             break;
+
         case 0:
             xfce_setenv ("DISPLAY", gdkdisplay_name, TRUE);
             g_free (gdkdisplay_name);
@@ -529,8 +557,16 @@ _item_setup (XfceExternalPanelItem * item, const char *file)
             g_critical ("Could not run plugin: %s", g_strerror (errno));
             gtk_widget_destroy (GTK_WIDGET (item));
             _exit (1);
+            break;
+
         default:
             /* parent: do nothing */;
+            if (!priv->restart)
+            {
+                g_signal_connect (item, "screen-changed", 
+                                  G_CALLBACK (_item_screen_changed), NULL);
+            }
+            break;
     }
     
     g_free (gdkdisplay_name);
@@ -572,6 +608,7 @@ xfce_external_panel_item_new (const char *name,
     priv->display_name    = g_strdup (display_name);
     priv->size            = size;
     priv->screen_position = position;
+    priv->file            = g_strdup (file);
 
     g_signal_connect_after (item, "realize", G_CALLBACK (_item_setup),
 			    (gpointer) file);
