@@ -1,6 +1,6 @@
 /* vim: set expandtab ts=8 sw=4: */
 
-/*  $Id: launcher-dialog.c 25792 2007-06-10 09:48:20Z jasper $
+/*  $Id: launcher-dialog.c 26937 2008-05-08 05:06:02Z kelnos $
  *
  *  Copyright © 2005 Jasper Huijsmans <jasper@xfce.org>
  *
@@ -1334,6 +1334,9 @@ launcher_properties_dialog (XfcePanelPlugin *plugin, LauncherPlugin * launcher)
                 GTK_STOCK_CLOSE, GTK_RESPONSE_OK,
                 NULL);
 
+    gtk_window_set_screen (GTK_WINDOW (ld->dlg),
+                           gtk_widget_get_screen (GTK_WIDGET (plugin)));
+
     g_object_set_data (G_OBJECT (plugin), "dialog", ld->dlg);
     g_object_set_data (G_OBJECT (plugin), "launcher-dialog", ld);
 
